<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "تم ترفيع الملفات بنجاح.",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
"The uploaded file was only partially uploaded" => "تم ترفيع جزء من الملفات الذي تريد ترفيعها فقط",
"No file was uploaded" => "لم يتم ترفيع أي من الملفات",
"Missing a temporary folder" => "المجلد المؤقت غير موجود",
"Files" => "الملفات",
"Share" => "شارك",
"Delete permanently" => "حذف بشكل دائم",
"Delete" => "محذوف",
"Close" => "إغلق",
"Name" => "الاسم",
"Size" => "حجم",
"Modified" => "معدل",
"Upload" => "إرفع",
"Maximum upload size" => "الحد الأقصى لحجم الملفات التي يمكن رفعها",
"Save" => "حفظ",
"New" => "جديد",
"Text file" => "ملف",
"Folder" => "مجلد",
"Nothing in here. Upload something!" => "لا يوجد شيء هنا. إرفع بعض الملفات!",
"Download" => "تحميل",
"Unshare" => "إلغاء مشاركة",
"Upload too large" => "حجم الترفيع أعلى من المسموح",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم."
);
